@@ -115,7 +115,6 @@ impl<T> Drop for Entry<T> {
 
 unsafe impl<T: Send> Send for Entry<T> {}
 
-
 /// The multi-producer single-consumer structure. This is not cloneable, but it
 /// may be safely shared so long as it is guaranteed that there is only one
 /// popper at a time (many pushers are allowed).
@@ -195,7 +194,8 @@ impl<T> Queue<T> {
     }
 
     pub fn pop_if<F>(&self, f: &F) -> Option<T>
-        where F: Fn(&T) -> bool
+    where
+        F: Fn(&T) -> bool,
     {
         unsafe {
             let tail = *self.tail.get();
